pub struct ServiceOperationMetadata {
pub operation_id: Option<String>,
pub summary: Option<String>,
pub input_schema: Option<Value>,
pub output_schema: Option<Value>,
pub safe_probe: Option<ServiceOperationSafeProbe>,
pub timeout_ms: Option<u64>,
pub idempotency: Option<ServiceOperationIdempotency>,
}Fields
operation_id: Option<String>summary: Option<String>input_schema: Option<Value>output_schema: Option<Value>safe_probe: Option<ServiceOperationSafeProbe>timeout_ms: Option<u64>idempotency: Option<ServiceOperationIdempotency>Trait Implementations
Sourceimpl Clone for ServiceOperationMetadata
impl Clone for ServiceOperationMetadata
Sourcefn clone(&self) -> ServiceOperationMetadata
fn clone(&self) -> ServiceOperationMetadata
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ServiceOperationMetadata
impl ComposeSchema for ServiceOperationMetadata
Sourceimpl Debug for ServiceOperationMetadata
impl Debug for ServiceOperationMetadata
Sourceimpl Default for ServiceOperationMetadata
impl Default for ServiceOperationMetadata
Sourcefn default() -> ServiceOperationMetadata
fn default() -> ServiceOperationMetadata
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ServiceOperationMetadata
impl<'de> Deserialize<'de> for ServiceOperationMetadata
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ServiceOperationMetadata
Sourceimpl JsonSchema for ServiceOperationMetadata
impl JsonSchema for ServiceOperationMetadata
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ServiceOperationMetadata
impl PartialEq for ServiceOperationMetadata
Sourceimpl Serialize for ServiceOperationMetadata
impl Serialize for ServiceOperationMetadata
impl StructuralPartialEq for ServiceOperationMetadata