pub struct AdminActionConfirmation {
pub message: String,
pub required_phrase: Option<String>,
}Fields
message: Stringrequired_phrase: Option<String>Trait Implementations
Sourceimpl Clone for AdminActionConfirmation
impl Clone for AdminActionConfirmation
Sourcefn clone(&self) -> AdminActionConfirmation
fn clone(&self) -> AdminActionConfirmation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for AdminActionConfirmation
impl ComposeSchema for AdminActionConfirmation
Sourceimpl Debug for AdminActionConfirmation
impl Debug for AdminActionConfirmation
Sourceimpl<'de> Deserialize<'de> for AdminActionConfirmation
impl<'de> Deserialize<'de> for AdminActionConfirmation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AdminActionConfirmation
Sourceimpl JsonSchema for AdminActionConfirmation
impl JsonSchema for AdminActionConfirmation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AdminActionConfirmation
impl PartialEq for AdminActionConfirmation
Sourceimpl Serialize for AdminActionConfirmation
impl Serialize for AdminActionConfirmation
impl StructuralPartialEq for AdminActionConfirmation