pub struct AdminActionInputField {
pub name: String,
pub label: String,
pub field_type: FieldType,
pub required: bool,
pub description: Option<String>,
}Fields
name: Stringlabel: Stringfield_type: FieldTyperequired: booldescription: Option<String>Trait Implementations
Sourceimpl Clone for AdminActionInputField
impl Clone for AdminActionInputField
Sourcefn clone(&self) -> AdminActionInputField
fn clone(&self) -> AdminActionInputField
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for AdminActionInputField
impl ComposeSchema for AdminActionInputField
Sourceimpl Debug for AdminActionInputField
impl Debug for AdminActionInputField
Sourceimpl<'de> Deserialize<'de> for AdminActionInputField
impl<'de> Deserialize<'de> for AdminActionInputField
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AdminActionInputField
Sourceimpl JsonSchema for AdminActionInputField
impl JsonSchema for AdminActionInputField
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AdminActionInputField
impl PartialEq for AdminActionInputField
Sourceimpl Serialize for AdminActionInputField
impl Serialize for AdminActionInputField
impl StructuralPartialEq for AdminActionInputField