pub struct AdminDeclarativePage {
pub name: String,
pub label: String,
pub sections: Vec<AdminDeclarativeSection>,
}Fields
name: Stringlabel: Stringsections: Vec<AdminDeclarativeSection>Trait Implementations
Sourceimpl Clone for AdminDeclarativePage
impl Clone for AdminDeclarativePage
Sourcefn clone(&self) -> AdminDeclarativePage
fn clone(&self) -> AdminDeclarativePage
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for AdminDeclarativePage
impl ComposeSchema for AdminDeclarativePage
Sourceimpl Debug for AdminDeclarativePage
impl Debug for AdminDeclarativePage
Sourceimpl<'de> Deserialize<'de> for AdminDeclarativePage
impl<'de> Deserialize<'de> for AdminDeclarativePage
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AdminDeclarativePage
Sourceimpl JsonSchema for AdminDeclarativePage
impl JsonSchema for AdminDeclarativePage
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AdminDeclarativePage
impl PartialEq for AdminDeclarativePage
Sourceimpl Serialize for AdminDeclarativePage
impl Serialize for AdminDeclarativePage
impl StructuralPartialEq for AdminDeclarativePage