pub struct AdminDeclarativeSection {
pub name: String,
pub label: String,
pub component: AdminDeclarativeComponent,
}Fields
name: Stringlabel: Stringcomponent: AdminDeclarativeComponentTrait Implementations
Sourceimpl Clone for AdminDeclarativeSection
impl Clone for AdminDeclarativeSection
Sourcefn clone(&self) -> AdminDeclarativeSection
fn clone(&self) -> AdminDeclarativeSection
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for AdminDeclarativeSection
impl ComposeSchema for AdminDeclarativeSection
Sourceimpl Debug for AdminDeclarativeSection
impl Debug for AdminDeclarativeSection
Sourceimpl<'de> Deserialize<'de> for AdminDeclarativeSection
impl<'de> Deserialize<'de> for AdminDeclarativeSection
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AdminDeclarativeSection
Sourceimpl JsonSchema for AdminDeclarativeSection
impl JsonSchema for AdminDeclarativeSection
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AdminDeclarativeSection
impl PartialEq for AdminDeclarativeSection
Sourceimpl Serialize for AdminDeclarativeSection
impl Serialize for AdminDeclarativeSection
impl StructuralPartialEq for AdminDeclarativeSection