pub struct AdminDeclarativeSurface {
pub pages: Vec<AdminDeclarativePage>,
pub actions: Vec<AdminAction>,
pub fallback_schema: Option<AdminSchema>,
}Fields
pages: Vec<AdminDeclarativePage>actions: Vec<AdminAction>fallback_schema: Option<AdminSchema>Trait Implementations
Sourceimpl Clone for AdminDeclarativeSurface
impl Clone for AdminDeclarativeSurface
Sourcefn clone(&self) -> AdminDeclarativeSurface
fn clone(&self) -> AdminDeclarativeSurface
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for AdminDeclarativeSurface
impl ComposeSchema for AdminDeclarativeSurface
Sourceimpl Debug for AdminDeclarativeSurface
impl Debug for AdminDeclarativeSurface
Sourceimpl<'de> Deserialize<'de> for AdminDeclarativeSurface
impl<'de> Deserialize<'de> for AdminDeclarativeSurface
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AdminDeclarativeSurface
Sourceimpl JsonSchema for AdminDeclarativeSurface
impl JsonSchema for AdminDeclarativeSurface
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AdminDeclarativeSurface
impl PartialEq for AdminDeclarativeSurface
Sourceimpl Serialize for AdminDeclarativeSurface
impl Serialize for AdminDeclarativeSurface
impl StructuralPartialEq for AdminDeclarativeSurface