pub struct AdminSandboxPolicy {
pub allow_scripts: bool,
pub allow_forms: bool,
pub allow_popups: bool,
pub allow_same_origin: bool,
}Fields
allow_scripts: boolallow_forms: boolallow_popups: boolallow_same_origin: boolTrait Implementations
Sourceimpl Clone for AdminSandboxPolicy
impl Clone for AdminSandboxPolicy
Sourcefn clone(&self) -> AdminSandboxPolicy
fn clone(&self) -> AdminSandboxPolicy
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for AdminSandboxPolicy
impl ComposeSchema for AdminSandboxPolicy
Sourceimpl Debug for AdminSandboxPolicy
impl Debug for AdminSandboxPolicy
Sourceimpl<'de> Deserialize<'de> for AdminSandboxPolicy
impl<'de> Deserialize<'de> for AdminSandboxPolicy
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AdminSandboxPolicy
Sourceimpl JsonSchema for AdminSandboxPolicy
impl JsonSchema for AdminSandboxPolicy
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AdminSandboxPolicy
impl PartialEq for AdminSandboxPolicy
Sourceimpl Serialize for AdminSandboxPolicy
impl Serialize for AdminSandboxPolicy
impl StructuralPartialEq for AdminSandboxPolicy