pub struct ArtifactAttestationEvidence {
pub attestation: AttestationReference,
pub repository: String,
pub repository_id: u64,
pub workflow: String,
pub run_id: u64,
pub commit_sha: String,
pub oidc_issuer: String,
pub runner_environment: String,
}Fields
attestation: AttestationReferencerepository: Stringrepository_id: u64workflow: Stringrun_id: u64commit_sha: Stringoidc_issuer: Stringrunner_environment: StringTrait Implementations
Sourceimpl Clone for ArtifactAttestationEvidence
impl Clone for ArtifactAttestationEvidence
Sourcefn clone(&self) -> ArtifactAttestationEvidence
fn clone(&self) -> ArtifactAttestationEvidence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ArtifactAttestationEvidence
impl Debug for ArtifactAttestationEvidence
Sourceimpl<'de> Deserialize<'de> for ArtifactAttestationEvidence
impl<'de> Deserialize<'de> for ArtifactAttestationEvidence
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ArtifactAttestationEvidence
Sourceimpl JsonSchema for ArtifactAttestationEvidence
impl JsonSchema for ArtifactAttestationEvidence
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ArtifactAttestationEvidence