pub struct ArtifactReference {
pub locator: String,
pub digest: String,
}Fields
locator: Stringdigest: StringTrait Implementations
Sourceimpl Clone for ArtifactReference
impl Clone for ArtifactReference
Sourcefn clone(&self) -> ArtifactReference
fn clone(&self) -> ArtifactReference
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ArtifactReference
impl Debug for ArtifactReference
Sourceimpl<'de> Deserialize<'de> for ArtifactReference
impl<'de> Deserialize<'de> for ArtifactReference
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ArtifactReference
Sourceimpl JsonSchema for ArtifactReference
impl JsonSchema for ArtifactReference
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ArtifactReference
impl PartialEq for ArtifactReference
Sourceimpl Serialize for ArtifactReference
impl Serialize for ArtifactReference
impl StructuralPartialEq for ArtifactReference