pub struct AttestationReference {
pub locator: String,
pub digest: String,
pub issuer: String,
pub signer: String,
}Fields
locator: Stringdigest: Stringissuer: Stringsigner: StringTrait Implementations
Sourceimpl Clone for AttestationReference
impl Clone for AttestationReference
Sourcefn clone(&self) -> AttestationReference
fn clone(&self) -> AttestationReference
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AttestationReference
impl Debug for AttestationReference
Sourceimpl<'de> Deserialize<'de> for AttestationReference
impl<'de> Deserialize<'de> for AttestationReference
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AttestationReference
Sourceimpl JsonSchema for AttestationReference
impl JsonSchema for AttestationReference
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AttestationReference
impl PartialEq for AttestationReference
Sourceimpl Serialize for AttestationReference
impl Serialize for AttestationReference
impl StructuralPartialEq for AttestationReference