pub struct AttestedVerificationReceipt {
pub receipt: ModuleVerificationReceipt,
pub receipt_digest: String,
pub attestation: AttestationReference,
}Fields
receipt: ModuleVerificationReceiptreceipt_digest: Stringattestation: AttestationReferenceTrait Implementations
Sourceimpl Clone for AttestedVerificationReceipt
impl Clone for AttestedVerificationReceipt
Sourcefn clone(&self) -> AttestedVerificationReceipt
fn clone(&self) -> AttestedVerificationReceipt
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AttestedVerificationReceipt
impl Debug for AttestedVerificationReceipt
Sourceimpl<'de> Deserialize<'de> for AttestedVerificationReceipt
impl<'de> Deserialize<'de> for AttestedVerificationReceipt
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AttestedVerificationReceipt
Sourceimpl JsonSchema for AttestedVerificationReceipt
impl JsonSchema for AttestedVerificationReceipt
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for AttestedVerificationReceipt