pub struct CatalogApproval {
pub actor: GitHubIdentity,
pub source_revision: String,
pub approved_at: DateTime<Utc>,
}Fields
actor: GitHubIdentitysource_revision: Stringapproved_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for CatalogApproval
impl Clone for CatalogApproval
Sourcefn clone(&self) -> CatalogApproval
fn clone(&self) -> CatalogApproval
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CatalogApproval
impl Debug for CatalogApproval
Sourceimpl<'de> Deserialize<'de> for CatalogApproval
impl<'de> Deserialize<'de> for CatalogApproval
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CatalogApproval
Sourceimpl JsonSchema for CatalogApproval
impl JsonSchema for CatalogApproval
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CatalogApproval
impl PartialEq for CatalogApproval
Sourceimpl Serialize for CatalogApproval
impl Serialize for CatalogApproval
impl StructuralPartialEq for CatalogApproval