pub struct CatalogModuleMetadata {
pub module_id: String,
pub description: String,
pub categories: Vec<String>,
pub documentation: Vec<String>,
pub source_revision: String,
}Fields
module_id: Stringdescription: Stringcategories: Vec<String>documentation: Vec<String>source_revision: StringTrait Implementations
Sourceimpl Clone for CatalogModuleMetadata
impl Clone for CatalogModuleMetadata
Sourcefn clone(&self) -> CatalogModuleMetadata
fn clone(&self) -> CatalogModuleMetadata
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CatalogModuleMetadata
impl Debug for CatalogModuleMetadata
Sourceimpl<'de> Deserialize<'de> for CatalogModuleMetadata
impl<'de> Deserialize<'de> for CatalogModuleMetadata
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CatalogModuleMetadata
Sourceimpl JsonSchema for CatalogModuleMetadata
impl JsonSchema for CatalogModuleMetadata
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CatalogModuleMetadata
impl PartialEq for CatalogModuleMetadata
Sourceimpl Serialize for CatalogModuleMetadata
impl Serialize for CatalogModuleMetadata
impl StructuralPartialEq for CatalogModuleMetadata