pub struct CatalogSnapshot {Show 13 fields
pub protocol: String,
pub source_revision: String,
pub generated_at: DateTime<Utc>,
pub previous_snapshot_digest: Option<String>,
pub verification_profile: VerificationProfile,
pub verification_profile_digest: String,
pub publishers: Vec<PublisherRecord>,
pub metadata: Vec<CatalogModuleMetadata>,
pub releases: Vec<CatalogReleaseRecord>,
pub lifecycle: Vec<ModuleLifecycleRecord>,
pub linked_provenance: Vec<LinkedProvenanceReceipt>,
pub verification_receipts: Vec<AttestedVerificationReceipt>,
pub verification_revocations: Vec<VerificationRevocation>,
}Fields
protocol: Stringsource_revision: Stringgenerated_at: DateTime<Utc>previous_snapshot_digest: Option<String>verification_profile: VerificationProfileverification_profile_digest: Stringpublishers: Vec<PublisherRecord>metadata: Vec<CatalogModuleMetadata>releases: Vec<CatalogReleaseRecord>lifecycle: Vec<ModuleLifecycleRecord>linked_provenance: Vec<LinkedProvenanceReceipt>verification_receipts: Vec<AttestedVerificationReceipt>verification_revocations: Vec<VerificationRevocation>Trait Implementations
Sourceimpl Clone for CatalogSnapshot
impl Clone for CatalogSnapshot
Sourcefn clone(&self) -> CatalogSnapshot
fn clone(&self) -> CatalogSnapshot
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CatalogSnapshot
impl Debug for CatalogSnapshot
Sourceimpl<'de> Deserialize<'de> for CatalogSnapshot
impl<'de> Deserialize<'de> for CatalogSnapshot
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CatalogSnapshot
Sourceimpl JsonSchema for CatalogSnapshot
impl JsonSchema for CatalogSnapshot
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CatalogSnapshot
impl PartialEq for CatalogSnapshot
Sourceimpl Serialize for CatalogSnapshot
impl Serialize for CatalogSnapshot
impl StructuralPartialEq for CatalogSnapshot