pub struct CatalogSnapshotEnvelope {
pub snapshot: CatalogSnapshot,
pub snapshot_digest: String,
pub attestation: AttestationReference,
}Fields
snapshot: CatalogSnapshotsnapshot_digest: Stringattestation: AttestationReferenceTrait Implementations
Sourceimpl Clone for CatalogSnapshotEnvelope
impl Clone for CatalogSnapshotEnvelope
Sourcefn clone(&self) -> CatalogSnapshotEnvelope
fn clone(&self) -> CatalogSnapshotEnvelope
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CatalogSnapshotEnvelope
impl Debug for CatalogSnapshotEnvelope
Sourceimpl<'de> Deserialize<'de> for CatalogSnapshotEnvelope
impl<'de> Deserialize<'de> for CatalogSnapshotEnvelope
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CatalogSnapshotEnvelope
Sourceimpl JsonSchema for CatalogSnapshotEnvelope
impl JsonSchema for CatalogSnapshotEnvelope
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CatalogSnapshotEnvelope
impl PartialEq for CatalogSnapshotEnvelope
Sourceimpl Serialize for CatalogSnapshotEnvelope
impl Serialize for CatalogSnapshotEnvelope
impl StructuralPartialEq for CatalogSnapshotEnvelope