pub struct ConsoleModuleSurface {
pub id: String,
pub path: String,
pub label: String,
pub area: ConsoleSurfaceArea,
pub required_capabilities: Vec<String>,
pub icon: Option<String>,
pub navigation: Option<ConsoleNavigation>,
}Fields
id: Stringpath: Stringlabel: Stringarea: ConsoleSurfaceArearequired_capabilities: Vec<String>icon: Option<String>Trait Implementations
Sourceimpl Clone for ConsoleModuleSurface
impl Clone for ConsoleModuleSurface
Sourcefn clone(&self) -> ConsoleModuleSurface
fn clone(&self) -> ConsoleModuleSurface
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ConsoleModuleSurface
impl ComposeSchema for ConsoleModuleSurface
Sourceimpl Debug for ConsoleModuleSurface
impl Debug for ConsoleModuleSurface
Sourceimpl<'de> Deserialize<'de> for ConsoleModuleSurface
impl<'de> Deserialize<'de> for ConsoleModuleSurface
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ConsoleModuleSurface
Sourceimpl JsonSchema for ConsoleModuleSurface
impl JsonSchema for ConsoleModuleSurface
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ConsoleModuleSurface
impl PartialEq for ConsoleModuleSurface
Sourceimpl Serialize for ConsoleModuleSurface
impl Serialize for ConsoleModuleSurface
impl StructuralPartialEq for ConsoleModuleSurface