pub struct ConsolePermissionGrant {
pub module_id: String,
pub module_release_digest: String,
pub ui_artifact_digest: Option<String>,
pub granted_permissions: Vec<String>,
}Fields
module_id: Stringmodule_release_digest: Stringui_artifact_digest: Option<String>granted_permissions: Vec<String>Trait Implementations
Sourceimpl Clone for ConsolePermissionGrant
impl Clone for ConsolePermissionGrant
Sourcefn clone(&self) -> ConsolePermissionGrant
fn clone(&self) -> ConsolePermissionGrant
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ConsolePermissionGrant
impl ComposeSchema for ConsolePermissionGrant
Sourceimpl Debug for ConsolePermissionGrant
impl Debug for ConsolePermissionGrant
Sourceimpl<'de> Deserialize<'de> for ConsolePermissionGrant
impl<'de> Deserialize<'de> for ConsolePermissionGrant
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ConsolePermissionGrant
Sourceimpl JsonSchema for ConsolePermissionGrant
impl JsonSchema for ConsolePermissionGrant
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ConsolePermissionGrant
impl PartialEq for ConsolePermissionGrant
Sourceimpl Serialize for ConsolePermissionGrant
impl Serialize for ConsolePermissionGrant
impl StructuralPartialEq for ConsolePermissionGrant