pub struct ConsoleSlot {
pub id: String,
pub version: u32,
pub label: String,
pub accepts: Vec<ConsoleContributionKind>,
pub context: Vec<ConsoleSlotContext>,
}Fields
id: Stringversion: u32label: Stringaccepts: Vec<ConsoleContributionKind>context: Vec<ConsoleSlotContext>Trait Implementations
Sourceimpl Clone for ConsoleSlot
impl Clone for ConsoleSlot
Sourcefn clone(&self) -> ConsoleSlot
fn clone(&self) -> ConsoleSlot
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ConsoleSlot
impl ComposeSchema for ConsoleSlot
Sourceimpl Debug for ConsoleSlot
impl Debug for ConsoleSlot
Sourceimpl<'de> Deserialize<'de> for ConsoleSlot
impl<'de> Deserialize<'de> for ConsoleSlot
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ConsoleSlot
Sourceimpl JsonSchema for ConsoleSlot
impl JsonSchema for ConsoleSlot
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ConsoleSlot
impl PartialEq for ConsoleSlot
Sourceimpl Serialize for ConsoleSlot
impl Serialize for ConsoleSlot
impl StructuralPartialEq for ConsoleSlot