pub struct ConsoleUiArtifact {
pub artifact: ArtifactReference,
pub format: ConsoleUiArtifactFormat,
pub entries: Vec<ConsoleUiArtifactEntry>,
pub bridge_protocol: String,
pub requested_permissions: Vec<ConsolePermissionRequest>,
pub provenance: Vec<ArtifactReference>,
}Fields
artifact: ArtifactReferenceformat: ConsoleUiArtifactFormatentries: Vec<ConsoleUiArtifactEntry>bridge_protocol: Stringrequested_permissions: Vec<ConsolePermissionRequest>provenance: Vec<ArtifactReference>Trait Implementations
Sourceimpl Clone for ConsoleUiArtifact
impl Clone for ConsoleUiArtifact
Sourcefn clone(&self) -> ConsoleUiArtifact
fn clone(&self) -> ConsoleUiArtifact
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConsoleUiArtifact
impl Debug for ConsoleUiArtifact
Sourceimpl<'de> Deserialize<'de> for ConsoleUiArtifact
impl<'de> Deserialize<'de> for ConsoleUiArtifact
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ConsoleUiArtifact
Sourceimpl JsonSchema for ConsoleUiArtifact
impl JsonSchema for ConsoleUiArtifact
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ConsoleUiArtifact
impl PartialEq for ConsoleUiArtifact
Sourceimpl Serialize for ConsoleUiArtifact
impl Serialize for ConsoleUiArtifact
impl StructuralPartialEq for ConsoleUiArtifact