pub struct ConsoleUiArtifactEntry {
pub name: String,
pub path: String,
}Fields
name: Stringpath: StringTrait Implementations
Sourceimpl Clone for ConsoleUiArtifactEntry
impl Clone for ConsoleUiArtifactEntry
Sourcefn clone(&self) -> ConsoleUiArtifactEntry
fn clone(&self) -> ConsoleUiArtifactEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConsoleUiArtifactEntry
impl Debug for ConsoleUiArtifactEntry
Sourceimpl<'de> Deserialize<'de> for ConsoleUiArtifactEntry
impl<'de> Deserialize<'de> for ConsoleUiArtifactEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ConsoleUiArtifactEntry
Sourceimpl JsonSchema for ConsoleUiArtifactEntry
impl JsonSchema for ConsoleUiArtifactEntry
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ConsoleUiArtifactEntry
impl PartialEq for ConsoleUiArtifactEntry
Sourceimpl Serialize for ConsoleUiArtifactEntry
impl Serialize for ConsoleUiArtifactEntry
impl StructuralPartialEq for ConsoleUiArtifactEntry