pub struct EventHandlerDeclaration {
pub name: String,
pub event_name: String,
pub operation: Option<ServiceOperationMetadata>,
}Fields
name: StringStable handler name used by Service Providers as the invoke path.
event_name: StringStable event name consumed from platform.outbox, e.g.
identity.user_registered.v1.
operation: Option<ServiceOperationMetadata>Trait Implementations
Sourceimpl Clone for EventHandlerDeclaration
impl Clone for EventHandlerDeclaration
Sourcefn clone(&self) -> EventHandlerDeclaration
fn clone(&self) -> EventHandlerDeclaration
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for EventHandlerDeclaration
impl ComposeSchema for EventHandlerDeclaration
Sourceimpl Debug for EventHandlerDeclaration
impl Debug for EventHandlerDeclaration
Sourceimpl<'de> Deserialize<'de> for EventHandlerDeclaration
impl<'de> Deserialize<'de> for EventHandlerDeclaration
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for EventHandlerDeclaration
Sourceimpl JsonSchema for EventHandlerDeclaration
impl JsonSchema for EventHandlerDeclaration
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for EventHandlerDeclaration
impl PartialEq for EventHandlerDeclaration
Sourceimpl Serialize for EventHandlerDeclaration
impl Serialize for EventHandlerDeclaration
impl StructuralPartialEq for EventHandlerDeclaration