pub struct GitHubIdentity {
pub login: String,
pub user_id: u64,
}Fields
login: Stringuser_id: u64Trait Implementations
Sourceimpl Clone for GitHubIdentity
impl Clone for GitHubIdentity
Sourcefn clone(&self) -> GitHubIdentity
fn clone(&self) -> GitHubIdentity
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GitHubIdentity
impl Debug for GitHubIdentity
Sourceimpl<'de> Deserialize<'de> for GitHubIdentity
impl<'de> Deserialize<'de> for GitHubIdentity
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for GitHubIdentity
Sourceimpl JsonSchema for GitHubIdentity
impl JsonSchema for GitHubIdentity
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for GitHubIdentity
impl PartialEq for GitHubIdentity
Sourceimpl Serialize for GitHubIdentity
impl Serialize for GitHubIdentity
impl StructuralPartialEq for GitHubIdentity