pub struct LifecycleActivationJobDeclaration {
pub name: String,
pub function_name: String,
pub run_policy: LifecycleActivationRunPolicy,
pub input: Value,
pub required: bool,
}Fields
name: Stringfunction_name: Stringrun_policy: LifecycleActivationRunPolicyinput: Valuerequired: boolTrait Implementations
Sourceimpl Clone for LifecycleActivationJobDeclaration
impl Clone for LifecycleActivationJobDeclaration
Sourcefn clone(&self) -> LifecycleActivationJobDeclaration
fn clone(&self) -> LifecycleActivationJobDeclaration
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for LifecycleActivationJobDeclaration
impl ComposeSchema for LifecycleActivationJobDeclaration
Sourceimpl<'de> Deserialize<'de> for LifecycleActivationJobDeclaration
impl<'de> Deserialize<'de> for LifecycleActivationJobDeclaration
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for LifecycleActivationJobDeclaration
Sourceimpl JsonSchema for LifecycleActivationJobDeclaration
impl JsonSchema for LifecycleActivationJobDeclaration
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for LifecycleActivationJobDeclaration