pub struct LifecycleStartupCheckDeclaration {
pub name: String,
pub required: bool,
pub check: LifecycleStartupCheckKind,
}Fields
name: Stringrequired: boolcheck: LifecycleStartupCheckKindTrait Implementations
Sourceimpl Clone for LifecycleStartupCheckDeclaration
impl Clone for LifecycleStartupCheckDeclaration
Sourcefn clone(&self) -> LifecycleStartupCheckDeclaration
fn clone(&self) -> LifecycleStartupCheckDeclaration
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for LifecycleStartupCheckDeclaration
impl ComposeSchema for LifecycleStartupCheckDeclaration
Sourceimpl<'de> Deserialize<'de> for LifecycleStartupCheckDeclaration
impl<'de> Deserialize<'de> for LifecycleStartupCheckDeclaration
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for LifecycleStartupCheckDeclaration
Sourceimpl JsonSchema for LifecycleStartupCheckDeclaration
impl JsonSchema for LifecycleStartupCheckDeclaration
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for LifecycleStartupCheckDeclaration