pub struct LinkedProvenanceReceipt {Show 13 fields
pub protocol: String,
pub receipt_id: String,
pub issued_at: DateTime<Utc>,
pub supersedes_receipt_digest: Option<String>,
pub publisher_id: String,
pub module_release_digest: String,
pub package: String,
pub crate_version: String,
pub archive_size: u64,
pub archive_checksum: String,
pub trusted_publishing: TrustedPublishingEvidence,
pub artifact_attestation: ArtifactAttestationEvidence,
pub clean_build: CleanBuildEvidence,
}Fields
protocol: Stringreceipt_id: Stringissued_at: DateTime<Utc>supersedes_receipt_digest: Option<String>publisher_id: Stringmodule_release_digest: Stringpackage: Stringcrate_version: Stringarchive_size: u64archive_checksum: Stringtrusted_publishing: TrustedPublishingEvidenceartifact_attestation: ArtifactAttestationEvidenceclean_build: CleanBuildEvidenceTrait Implementations
Sourceimpl Clone for LinkedProvenanceReceipt
impl Clone for LinkedProvenanceReceipt
Sourcefn clone(&self) -> LinkedProvenanceReceipt
fn clone(&self) -> LinkedProvenanceReceipt
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LinkedProvenanceReceipt
impl Debug for LinkedProvenanceReceipt
Sourceimpl<'de> Deserialize<'de> for LinkedProvenanceReceipt
impl<'de> Deserialize<'de> for LinkedProvenanceReceipt
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for LinkedProvenanceReceipt
Sourceimpl JsonSchema for LinkedProvenanceReceipt
impl JsonSchema for LinkedProvenanceReceipt
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for LinkedProvenanceReceipt
impl PartialEq for LinkedProvenanceReceipt
Sourceimpl Serialize for LinkedProvenanceReceipt
impl Serialize for LinkedProvenanceReceipt
impl StructuralPartialEq for LinkedProvenanceReceipt