pub struct ModuleCompatibilityDeclaration {
pub lenso_requirement: Option<String>,
pub host_api_requirement: Option<String>,
pub rust_requirement: Option<String>,
pub targets: Vec<String>,
pub transports: Vec<String>,
pub protocol_digests: Vec<String>,
}Fields
lenso_requirement: Option<String>host_api_requirement: Option<String>rust_requirement: Option<String>targets: Vec<String>transports: Vec<String>protocol_digests: Vec<String>Trait Implementations
Sourceimpl Clone for ModuleCompatibilityDeclaration
impl Clone for ModuleCompatibilityDeclaration
Sourcefn clone(&self) -> ModuleCompatibilityDeclaration
fn clone(&self) -> ModuleCompatibilityDeclaration
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ModuleCompatibilityDeclaration
impl Default for ModuleCompatibilityDeclaration
Sourcefn default() -> ModuleCompatibilityDeclaration
fn default() -> ModuleCompatibilityDeclaration
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ModuleCompatibilityDeclaration
impl<'de> Deserialize<'de> for ModuleCompatibilityDeclaration
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ModuleCompatibilityDeclaration
Sourceimpl JsonSchema for ModuleCompatibilityDeclaration
impl JsonSchema for ModuleCompatibilityDeclaration
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ModuleCompatibilityDeclaration