pub struct ModuleConfigContract {
pub fields: Vec<ModuleConfigField>,
}Fields
fields: Vec<ModuleConfigField>Trait Implementations
Sourceimpl Clone for ModuleConfigContract
impl Clone for ModuleConfigContract
Sourcefn clone(&self) -> ModuleConfigContract
fn clone(&self) -> ModuleConfigContract
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModuleConfigContract
impl Debug for ModuleConfigContract
Sourceimpl Default for ModuleConfigContract
impl Default for ModuleConfigContract
Sourcefn default() -> ModuleConfigContract
fn default() -> ModuleConfigContract
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ModuleConfigContract
impl<'de> Deserialize<'de> for ModuleConfigContract
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ModuleConfigContract
Sourceimpl JsonSchema for ModuleConfigContract
impl JsonSchema for ModuleConfigContract
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ModuleConfigContract
impl PartialEq for ModuleConfigContract
Sourceimpl Serialize for ModuleConfigContract
impl Serialize for ModuleConfigContract
impl StructuralPartialEq for ModuleConfigContract