pub struct ModuleConfigField {
pub key: String,
pub field_type: ModuleConfigFieldType,
pub required: bool,
pub scope: ModuleConfigScope,
pub sensitive: bool,
pub secret_reference: bool,
pub mutability: ModuleConfigMutability,
pub activation: ModuleConfigActivation,
pub default: Option<Value>,
pub validation: Option<ModuleConfigValidation>,
}Fields
key: Stringfield_type: ModuleConfigFieldTyperequired: boolscope: ModuleConfigScopesensitive: boolsecret_reference: boolmutability: ModuleConfigMutabilityactivation: ModuleConfigActivationdefault: Option<Value>validation: Option<ModuleConfigValidation>Trait Implementations
Sourceimpl Clone for ModuleConfigField
impl Clone for ModuleConfigField
Sourcefn clone(&self) -> ModuleConfigField
fn clone(&self) -> ModuleConfigField
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModuleConfigField
impl Debug for ModuleConfigField
Sourceimpl<'de> Deserialize<'de> for ModuleConfigField
impl<'de> Deserialize<'de> for ModuleConfigField
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ModuleConfigField
Sourceimpl JsonSchema for ModuleConfigField
impl JsonSchema for ModuleConfigField
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ModuleConfigField
impl PartialEq for ModuleConfigField
Sourceimpl Serialize for ModuleConfigField
impl Serialize for ModuleConfigField
impl StructuralPartialEq for ModuleConfigField