pub struct ModuleConfigValidation {
pub pattern: Option<String>,
pub minimum: Option<i64>,
pub maximum: Option<i64>,
pub allowed_values: Vec<String>,
}Fields
pattern: Option<String>minimum: Option<i64>maximum: Option<i64>allowed_values: Vec<String>Trait Implementations
Sourceimpl Clone for ModuleConfigValidation
impl Clone for ModuleConfigValidation
Sourcefn clone(&self) -> ModuleConfigValidation
fn clone(&self) -> ModuleConfigValidation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModuleConfigValidation
impl Debug for ModuleConfigValidation
Sourceimpl<'de> Deserialize<'de> for ModuleConfigValidation
impl<'de> Deserialize<'de> for ModuleConfigValidation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ModuleConfigValidation
Sourceimpl JsonSchema for ModuleConfigValidation
impl JsonSchema for ModuleConfigValidation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ModuleConfigValidation
impl PartialEq for ModuleConfigValidation
Sourceimpl Serialize for ModuleConfigValidation
impl Serialize for ModuleConfigValidation
impl StructuralPartialEq for ModuleConfigValidation