pub struct ModuleLifecycleState {
pub deprecated: bool,
pub yanked: bool,
pub security_blocked: bool,
}Fields
deprecated: boolyanked: boolsecurity_blocked: boolTrait Implementations
Sourceimpl Clone for ModuleLifecycleState
impl Clone for ModuleLifecycleState
Sourcefn clone(&self) -> ModuleLifecycleState
fn clone(&self) -> ModuleLifecycleState
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModuleLifecycleState
impl Debug for ModuleLifecycleState
Sourceimpl Default for ModuleLifecycleState
impl Default for ModuleLifecycleState
Sourcefn default() -> ModuleLifecycleState
fn default() -> ModuleLifecycleState
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ModuleLifecycleState
impl<'de> Deserialize<'de> for ModuleLifecycleState
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ModuleLifecycleState
Sourceimpl JsonSchema for ModuleLifecycleState
impl JsonSchema for ModuleLifecycleState
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ModuleLifecycleState
impl PartialEq for ModuleLifecycleState
Sourceimpl Serialize for ModuleLifecycleState
impl Serialize for ModuleLifecycleState
impl StructuralPartialEq for ModuleLifecycleState