pub struct ModuleMigrationDeclaration {
pub migration_id: String,
pub order: u32,
pub store: String,
pub destructive: bool,
pub reversible: bool,
pub activation: ModuleMigrationActivation,
}Fields
migration_id: Stringorder: u32store: Stringdestructive: boolreversible: boolactivation: ModuleMigrationActivationTrait Implementations
Sourceimpl Clone for ModuleMigrationDeclaration
impl Clone for ModuleMigrationDeclaration
Sourcefn clone(&self) -> ModuleMigrationDeclaration
fn clone(&self) -> ModuleMigrationDeclaration
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModuleMigrationDeclaration
impl Debug for ModuleMigrationDeclaration
Sourceimpl<'de> Deserialize<'de> for ModuleMigrationDeclaration
impl<'de> Deserialize<'de> for ModuleMigrationDeclaration
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ModuleMigrationDeclaration
Sourceimpl JsonSchema for ModuleMigrationDeclaration
impl JsonSchema for ModuleMigrationDeclaration
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ModuleMigrationDeclaration