pub struct ModuleTrustPolicy {
pub verification: VerificationRequirement,
pub maximum_mutation_age_seconds: u64,
pub stale_snapshot: StaleSnapshotPolicy,
pub compatibility: CompatibilityPolicy,
pub security_restore: SecurityRestorePolicy,
}Fields
verification: VerificationRequirementmaximum_mutation_age_seconds: u64stale_snapshot: StaleSnapshotPolicycompatibility: CompatibilityPolicysecurity_restore: SecurityRestorePolicyTrait Implementations
Sourceimpl Clone for ModuleTrustPolicy
impl Clone for ModuleTrustPolicy
Sourcefn clone(&self) -> ModuleTrustPolicy
fn clone(&self) -> ModuleTrustPolicy
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModuleTrustPolicy
impl Debug for ModuleTrustPolicy
Sourceimpl<'de> Deserialize<'de> for ModuleTrustPolicy
impl<'de> Deserialize<'de> for ModuleTrustPolicy
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ModuleTrustPolicy
Sourceimpl JsonSchema for ModuleTrustPolicy
impl JsonSchema for ModuleTrustPolicy
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ModuleTrustPolicy
impl PartialEq for ModuleTrustPolicy
Sourceimpl Serialize for ModuleTrustPolicy
impl Serialize for ModuleTrustPolicy
impl StructuralPartialEq for ModuleTrustPolicy