pub struct ModuleVerificationCell {Show 24 fields
pub module_release_digest: String,
pub operation: VerificationOperation,
pub source_release_digest: Option<String>,
pub lenso_version: String,
pub host_version: String,
pub cli_version: String,
pub starter_digest: String,
pub management_engine_version: String,
pub delivery_digest: String,
pub features: Vec<String>,
pub target: String,
pub os: String,
pub architecture: String,
pub runner_image_digest: String,
pub rust_version: String,
pub cargo_version: String,
pub store_engine: String,
pub store_version: String,
pub protocol_digests: Vec<String>,
pub console_artifact_digest: Option<String>,
pub console_host_api_version: Option<String>,
pub node_version: Option<String>,
pub package_manager_version: Option<String>,
pub console_lock_digest: Option<String>,
}Fields
module_release_digest: Stringoperation: VerificationOperationsource_release_digest: Option<String>lenso_version: Stringhost_version: Stringcli_version: Stringstarter_digest: Stringmanagement_engine_version: Stringdelivery_digest: Stringfeatures: Vec<String>target: Stringos: Stringarchitecture: Stringrunner_image_digest: Stringrust_version: Stringcargo_version: Stringstore_engine: Stringstore_version: Stringprotocol_digests: Vec<String>console_artifact_digest: Option<String>console_host_api_version: Option<String>node_version: Option<String>package_manager_version: Option<String>console_lock_digest: Option<String>Trait Implementations
Sourceimpl Clone for ModuleVerificationCell
impl Clone for ModuleVerificationCell
Sourcefn clone(&self) -> ModuleVerificationCell
fn clone(&self) -> ModuleVerificationCell
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModuleVerificationCell
impl Debug for ModuleVerificationCell
Sourceimpl<'de> Deserialize<'de> for ModuleVerificationCell
impl<'de> Deserialize<'de> for ModuleVerificationCell
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ModuleVerificationCell
Sourceimpl JsonSchema for ModuleVerificationCell
impl JsonSchema for ModuleVerificationCell
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ModuleVerificationCell
impl PartialEq for ModuleVerificationCell
Sourceimpl Serialize for ModuleVerificationCell
impl Serialize for ModuleVerificationCell
impl StructuralPartialEq for ModuleVerificationCell