pub struct ModuleVerificationReceipt {Show 15 fields
pub protocol: String,
pub receipt_id: String,
pub publisher_id: String,
pub manifest_digest: String,
pub catalog_snapshot_digest: String,
pub verification_profile_digest: String,
pub cell: ModuleVerificationCell,
pub outcome: VerificationOutcome,
pub started_at: DateTime<Utc>,
pub completed_at: DateTime<Utc>,
pub issues: Vec<String>,
pub toolchain_evidence: VerificationToolchainEvidence,
pub commands: Vec<String>,
pub checks: Vec<VerificationCheck>,
pub verifier: VerifierIdentity,
}Fields
protocol: Stringreceipt_id: Stringpublisher_id: Stringmanifest_digest: Stringcatalog_snapshot_digest: Stringverification_profile_digest: Stringcell: ModuleVerificationCelloutcome: VerificationOutcomestarted_at: DateTime<Utc>completed_at: DateTime<Utc>issues: Vec<String>toolchain_evidence: VerificationToolchainEvidencecommands: Vec<String>checks: Vec<VerificationCheck>verifier: VerifierIdentityTrait Implementations
Sourceimpl Clone for ModuleVerificationReceipt
impl Clone for ModuleVerificationReceipt
Sourcefn clone(&self) -> ModuleVerificationReceipt
fn clone(&self) -> ModuleVerificationReceipt
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModuleVerificationReceipt
impl Debug for ModuleVerificationReceipt
Sourceimpl<'de> Deserialize<'de> for ModuleVerificationReceipt
impl<'de> Deserialize<'de> for ModuleVerificationReceipt
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ModuleVerificationReceipt
Sourceimpl JsonSchema for ModuleVerificationReceipt
impl JsonSchema for ModuleVerificationReceipt
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ModuleVerificationReceipt