pub struct PublisherGovernanceDecision {
pub approved: bool,
pub reason_codes: Vec<String>,
}Fields
approved: boolreason_codes: Vec<String>Trait Implementations
Sourceimpl Clone for PublisherGovernanceDecision
impl Clone for PublisherGovernanceDecision
Sourcefn clone(&self) -> PublisherGovernanceDecision
fn clone(&self) -> PublisherGovernanceDecision
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PublisherGovernanceDecision
impl Debug for PublisherGovernanceDecision
Sourceimpl<'de> Deserialize<'de> for PublisherGovernanceDecision
impl<'de> Deserialize<'de> for PublisherGovernanceDecision
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for PublisherGovernanceDecision
Sourceimpl JsonSchema for PublisherGovernanceDecision
impl JsonSchema for PublisherGovernanceDecision
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for PublisherGovernanceDecision