pub struct PublisherRecord {
pub publisher_id: String,
pub namespaces: Vec<String>,
pub owner: GitHubIdentity,
pub maintainers: Vec<GitHubIdentity>,
pub github_owner_id: u64,
pub github_repository_id: u64,
pub repository: String,
pub publishing_workflow: String,
pub security_contact: String,
pub status: PublisherStatus,
pub source_revision: String,
}Fields
publisher_id: Stringnamespaces: Vec<String>owner: GitHubIdentitymaintainers: Vec<GitHubIdentity>github_owner_id: u64github_repository_id: u64repository: Stringpublishing_workflow: Stringsecurity_contact: Stringstatus: PublisherStatussource_revision: StringTrait Implementations
Sourceimpl Clone for PublisherRecord
impl Clone for PublisherRecord
Sourcefn clone(&self) -> PublisherRecord
fn clone(&self) -> PublisherRecord
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PublisherRecord
impl Debug for PublisherRecord
Sourceimpl<'de> Deserialize<'de> for PublisherRecord
impl<'de> Deserialize<'de> for PublisherRecord
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for PublisherRecord
Sourceimpl JsonSchema for PublisherRecord
impl JsonSchema for PublisherRecord
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PublisherRecord
impl PartialEq for PublisherRecord
Sourceimpl Serialize for PublisherRecord
impl Serialize for PublisherRecord
impl StructuralPartialEq for PublisherRecord