pub struct RuntimeFunctionDeclaration {
pub name: String,
pub version: u16,
pub queue: String,
pub input_schema: Option<String>,
pub retry_policy: Option<RuntimeRetryPolicyDeclaration>,
pub operation: Option<ServiceOperationMetadata>,
}Fields
name: StringStable function name used by runtime.function_runs.
version: u16Version for the declared function contract.
queue: StringQueue name the host should use when registering the function.
input_schema: Option<String>Optional schema identifier for the function input payload.
retry_policy: Option<RuntimeRetryPolicyDeclaration>Optional retry policy requested by the module. The host still owns enforcement and may clamp values when behavior registration is added.
operation: Option<ServiceOperationMetadata>Trait Implementations
Sourceimpl Clone for RuntimeFunctionDeclaration
impl Clone for RuntimeFunctionDeclaration
Sourcefn clone(&self) -> RuntimeFunctionDeclaration
fn clone(&self) -> RuntimeFunctionDeclaration
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for RuntimeFunctionDeclaration
impl ComposeSchema for RuntimeFunctionDeclaration
Sourceimpl Debug for RuntimeFunctionDeclaration
impl Debug for RuntimeFunctionDeclaration
Sourceimpl<'de> Deserialize<'de> for RuntimeFunctionDeclaration
impl<'de> Deserialize<'de> for RuntimeFunctionDeclaration
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RuntimeFunctionDeclaration
impl StructuralPartialEq for RuntimeFunctionDeclaration