pub struct RuntimeRetryPolicyDeclaration {
pub max_attempts: u32,
pub initial_delay_ms: u64,
}Fields
max_attempts: u32initial_delay_ms: u64Trait Implementations
Sourceimpl Clone for RuntimeRetryPolicyDeclaration
impl Clone for RuntimeRetryPolicyDeclaration
Sourcefn clone(&self) -> RuntimeRetryPolicyDeclaration
fn clone(&self) -> RuntimeRetryPolicyDeclaration
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for RuntimeRetryPolicyDeclaration
impl ComposeSchema for RuntimeRetryPolicyDeclaration
Sourceimpl<'de> Deserialize<'de> for RuntimeRetryPolicyDeclaration
impl<'de> Deserialize<'de> for RuntimeRetryPolicyDeclaration
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RuntimeRetryPolicyDeclaration
Sourceimpl JsonSchema for RuntimeRetryPolicyDeclaration
impl JsonSchema for RuntimeRetryPolicyDeclaration
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for RuntimeRetryPolicyDeclaration