pub struct VerificationCheck {
pub check_id: String,
pub outcome: VerificationCheckOutcome,
pub duration_ms: u64,
pub evidence: Vec<ArtifactReference>,
}Fields
check_id: Stringoutcome: VerificationCheckOutcomeduration_ms: u64evidence: Vec<ArtifactReference>Trait Implementations
Sourceimpl Clone for VerificationCheck
impl Clone for VerificationCheck
Sourcefn clone(&self) -> VerificationCheck
fn clone(&self) -> VerificationCheck
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VerificationCheck
impl Debug for VerificationCheck
Sourceimpl<'de> Deserialize<'de> for VerificationCheck
impl<'de> Deserialize<'de> for VerificationCheck
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for VerificationCheck
Sourceimpl JsonSchema for VerificationCheck
impl JsonSchema for VerificationCheck
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for VerificationCheck
impl PartialEq for VerificationCheck
Sourceimpl Serialize for VerificationCheck
impl Serialize for VerificationCheck
impl StructuralPartialEq for VerificationCheck