pub struct VerificationEvaluation {
pub state: VerificationState,
pub reason_code: String,
pub receipt_digests: Vec<String>,
}Fields
state: VerificationStatereason_code: Stringreceipt_digests: Vec<String>Trait Implementations
Sourceimpl Clone for VerificationEvaluation
impl Clone for VerificationEvaluation
Sourcefn clone(&self) -> VerificationEvaluation
fn clone(&self) -> VerificationEvaluation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VerificationEvaluation
impl Debug for VerificationEvaluation
Sourceimpl<'de> Deserialize<'de> for VerificationEvaluation
impl<'de> Deserialize<'de> for VerificationEvaluation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for VerificationEvaluation
Sourceimpl JsonSchema for VerificationEvaluation
impl JsonSchema for VerificationEvaluation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for VerificationEvaluation
impl PartialEq for VerificationEvaluation
Sourceimpl Serialize for VerificationEvaluation
impl Serialize for VerificationEvaluation
impl StructuralPartialEq for VerificationEvaluation