pub struct VerificationProfile {
pub protocol: String,
pub profile_id: String,
pub policy_revision: String,
pub required_checks: BTreeMap<VerificationOperation, Vec<String>>,
pub accepted_verifier_repository_ids: Vec<u64>,
pub accepted_verifier_workflows: Vec<String>,
}Fields
protocol: Stringprofile_id: Stringpolicy_revision: Stringrequired_checks: BTreeMap<VerificationOperation, Vec<String>>accepted_verifier_repository_ids: Vec<u64>accepted_verifier_workflows: Vec<String>Trait Implementations
Sourceimpl Clone for VerificationProfile
impl Clone for VerificationProfile
Sourcefn clone(&self) -> VerificationProfile
fn clone(&self) -> VerificationProfile
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VerificationProfile
impl Debug for VerificationProfile
Sourceimpl<'de> Deserialize<'de> for VerificationProfile
impl<'de> Deserialize<'de> for VerificationProfile
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for VerificationProfile
Sourceimpl JsonSchema for VerificationProfile
impl JsonSchema for VerificationProfile
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for VerificationProfile
impl PartialEq for VerificationProfile
Sourceimpl Serialize for VerificationProfile
impl Serialize for VerificationProfile
impl StructuralPartialEq for VerificationProfile