pub struct VerificationRevocation {
pub receipt_digest: String,
pub reason_code: String,
pub evidence_reference: String,
pub actor: GitHubIdentity,
pub source_revision: String,
pub effective_at: DateTime<Utc>,
}Fields
receipt_digest: Stringreason_code: Stringevidence_reference: Stringactor: GitHubIdentitysource_revision: Stringeffective_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for VerificationRevocation
impl Clone for VerificationRevocation
Sourcefn clone(&self) -> VerificationRevocation
fn clone(&self) -> VerificationRevocation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VerificationRevocation
impl Debug for VerificationRevocation
Sourceimpl<'de> Deserialize<'de> for VerificationRevocation
impl<'de> Deserialize<'de> for VerificationRevocation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for VerificationRevocation
Sourceimpl JsonSchema for VerificationRevocation
impl JsonSchema for VerificationRevocation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for VerificationRevocation
impl PartialEq for VerificationRevocation
Sourceimpl Serialize for VerificationRevocation
impl Serialize for VerificationRevocation
impl StructuralPartialEq for VerificationRevocation