pub struct VerifierIdentity {
pub repository: String,
pub repository_id: u64,
pub workflow: String,
pub run_id: u64,
pub commit_sha: String,
pub oidc_issuer: String,
pub signer: String,
}Fields
repository: Stringrepository_id: u64workflow: Stringrun_id: u64commit_sha: Stringoidc_issuer: Stringsigner: StringTrait Implementations
Sourceimpl Clone for VerifierIdentity
impl Clone for VerifierIdentity
Sourcefn clone(&self) -> VerifierIdentity
fn clone(&self) -> VerifierIdentity
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VerifierIdentity
impl Debug for VerifierIdentity
Sourceimpl<'de> Deserialize<'de> for VerifierIdentity
impl<'de> Deserialize<'de> for VerifierIdentity
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for VerifierIdentity
Sourceimpl JsonSchema for VerifierIdentity
impl JsonSchema for VerifierIdentity
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for VerifierIdentity
impl PartialEq for VerifierIdentity
Sourceimpl Serialize for VerifierIdentity
impl Serialize for VerifierIdentity
impl StructuralPartialEq for VerifierIdentity