pub struct WorkflowCompatibilityReason {
pub code: String,
pub path: String,
pub message: String,
pub next_action: String,
}Fields
code: Stringpath: Stringmessage: Stringnext_action: StringTrait Implementations
Sourceimpl Clone for WorkflowCompatibilityReason
impl Clone for WorkflowCompatibilityReason
Sourcefn clone(&self) -> WorkflowCompatibilityReason
fn clone(&self) -> WorkflowCompatibilityReason
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for WorkflowCompatibilityReason
impl ComposeSchema for WorkflowCompatibilityReason
Sourceimpl Debug for WorkflowCompatibilityReason
impl Debug for WorkflowCompatibilityReason
Sourceimpl<'de> Deserialize<'de> for WorkflowCompatibilityReason
impl<'de> Deserialize<'de> for WorkflowCompatibilityReason
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for WorkflowCompatibilityReason
Sourceimpl JsonSchema for WorkflowCompatibilityReason
impl JsonSchema for WorkflowCompatibilityReason
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for WorkflowCompatibilityReason
impl Ord for WorkflowCompatibilityReason
Sourcefn cmp(&self, other: &WorkflowCompatibilityReason) -> Ordering
fn cmp(&self, other: &WorkflowCompatibilityReason) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for WorkflowCompatibilityReason
impl PartialOrd for WorkflowCompatibilityReason
impl StructuralPartialEq for WorkflowCompatibilityReason