pub struct WorkflowCompatibilityResult {
pub protocol: String,
pub category: WorkflowCompatibilityCategory,
pub before: WorkflowDefinitionReference,
pub after: WorkflowDefinitionReference,
pub reasons: Vec<WorkflowCompatibilityReason>,
}Fields
protocol: Stringcategory: WorkflowCompatibilityCategorybefore: WorkflowDefinitionReferenceafter: WorkflowDefinitionReferencereasons: Vec<WorkflowCompatibilityReason>Trait Implementations
Sourceimpl Clone for WorkflowCompatibilityResult
impl Clone for WorkflowCompatibilityResult
Sourcefn clone(&self) -> WorkflowCompatibilityResult
fn clone(&self) -> WorkflowCompatibilityResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for WorkflowCompatibilityResult
impl ComposeSchema for WorkflowCompatibilityResult
Sourceimpl Debug for WorkflowCompatibilityResult
impl Debug for WorkflowCompatibilityResult
Sourceimpl<'de> Deserialize<'de> for WorkflowCompatibilityResult
impl<'de> Deserialize<'de> for WorkflowCompatibilityResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for WorkflowCompatibilityResult
Sourceimpl JsonSchema for WorkflowCompatibilityResult
impl JsonSchema for WorkflowCompatibilityResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for WorkflowCompatibilityResult