pub struct WorkflowCompensationDeclaration {
pub name: String,
pub order: u32,
pub contract: WorkflowDataContract,
pub completion_contract: WorkflowDataContract,
}Fields
name: StringStable compensation behavior identity within this Workflow Definition.
order: u32Explicit deterministic execution order. Lower values execute first.
contract: WorkflowDataContractVersioned Event Contract used to request the compensation effect.
completion_contract: WorkflowDataContractVersioned Event Contract that confirms the remote business effect was reversed.
Implementations
Sourceimpl WorkflowCompensationDeclaration
impl WorkflowCompensationDeclaration
pub fn new( name: impl Into<String>, order: u32, contract: WorkflowDataContract, ) -> Self
pub fn with_completion_contract(self, contract: WorkflowDataContract) -> Self