pub struct WorkflowStepDeclaration {
pub name: String,
pub display_name: Option<String>,
pub retry_policy: Option<WorkflowRetryPolicyDeclaration>,
pub timeout_ms: Option<u64>,
pub compensation: Option<WorkflowCompensationDeclaration>,
}Fields
name: Stringdisplay_name: Option<String>retry_policy: Option<WorkflowRetryPolicyDeclaration>Optional durable retry schedule. max_attempts includes the original
attempt, while each delay schedules the following attempt.
timeout_ms: Option<u64>Optional durable timeout applied independently to every attempt.
compensation: Option<WorkflowCompensationDeclaration>Optional compensation for the completed business effect produced by this step. The explicit order is evaluated across all completed effects when compensation is selected; it is independent from completion time.
Implementations
Sourceimpl WorkflowStepDeclaration
impl WorkflowStepDeclaration
pub fn new(name: impl Into<String>) -> Self
pub fn with_display_name(self, display_name: impl Into<String>) -> Self
pub fn with_retry_policy( self, retry_policy: WorkflowRetryPolicyDeclaration, ) -> Self
pub const fn with_timeout_ms(self, timeout_ms: u64) -> Self
pub fn with_compensation( self, compensation: WorkflowCompensationDeclaration, ) -> Self